It is the package for a few functions, still to be updated,
It has two classes inside 
class BasicMath
    methods add(a, b), sub(a, b), isPrime(num)
class ListFunctions
    methods colMatch(list1, list2, print=False)
